@@ -79,7 +79,7 @@ print.abcrf <- function(x, ...) {
   cat("\nCall:\n", deparse(x$call), "\n")
   if (x$lda) cat("includes the axes of a preliminary LDA\n\n")  
   cat("Number of simulations: ", length(x$model.rf$num.samples), "\n", sep="")
-  cat("     Prior error rate: ", round(x$prior.err * 100, digits = 4), "%\n\n", sep = "")
+  cat("Out-of-bag prior error rate: ", round(x$prior.err * 100, digits = 4), "%\n\n", sep = "")
   cat("Confusion matrix:\n")
   print(x$model.rf$confusion, ...)  
 }
\ No newline at end of file
