@@ -8,6 +8,7 @@ err.regAbcrf <- function(object, training, paral=FALSE, ncores= if(paral) max(de
     stop("incorrect number of CPU cores")
   
   ntrain <- nrow(training)
+  ntree <- object$model.rf$num.trees
   
   mf <- match.call(expand.dots=FALSE)
   mf <- mf[1]
@@ -22,26 +23,11 @@ err.regAbcrf <- function(object, training, paral=FALSE, ncores= if(paral) max(de
   
   pred <- predict(object$model.rf, training, predict.all=TRUE , num.threads=ncores)$predictions
   
-  if (object$model.rf$num.trees < 40) stop("the number of trees in the forest should be greater than 40")
+  if (ntree < 40) stop("the number of trees in the forest should be greater than 40")
   sequo <- seq(40,object$model.rf$num.trees, length.out = 20)
   
-  res <- rep(0,length(sequo))
-  h <- 0
-  pb=txtProgressBar(min=0,max=length(sequo),style=3)
-  for (j in sequo) 
-  {
-    mama <- rep(NA,ntrain)
-    for (i in 1:ntrain) 
-    {
-      outbag <- (1:j)[inbag[i,1:j]==0]
-      if (length(outbag)>0) mama[i] <- mean(pred[i,outbag])
-    }
-    h <- h+1
-    res[h] <- mean((mama-resp)^2)
-    setTxtProgressBar(pb,h)
-  }
-  close(pb)
+  res <- oobErrorsReg(as.integer(floor(sequo)), as.integer(ntrain), as.integer(ntree), as.numeric(resp), inbag, pred)
   
-  plot(sequo,res,ylab="out-of-bag mean squared error",xlab="Number of trees",type="l")
+  plot(floor(sequo), res, ylab="out-of-bag mean squared error",xlab="Number of trees",type="l")
   cbind(ntree=floor(sequo), oob_mse=res)
-}
+}
\ No newline at end of file
